package java.lang.reflect;

import java.security.AccessController;
import sun.reflect.ReflectionFactory;

public class Modifier
{
    public static final int PUBLIC = 1;
    public static final int PRIVATE = 2;
    public static final int PROTECTED = 4;
    public static final int STATIC = 8;
    public static final int FINAL = 16;
    public static final int SYNCHRONIZED = 32;
    public static final int VOLATILE = 64;
    public static final int TRANSIENT = 128;
    public static final int NATIVE = 256;
    public static final int INTERFACE = 512;
    public static final int ABSTRACT = 1024;
    public static final int STRICT = 2048;
    static final int BRIDGE = 64;
    static final int VARARGS = 128;
    static final int SYNTHETIC = 4096;
    static final int ANNOTATION = 8192;
    static final int ENUM = 16384;
    static final int MANDATED = 32768;
    private static final int CLASS_MODIFIERS = 3103;
    private static final int INTERFACE_MODIFIERS = 3087;
    private static final int CONSTRUCTOR_MODIFIERS = 7;
    private static final int METHOD_MODIFIERS = 3391;
    private static final int FIELD_MODIFIERS = 223;
    private static final int PARAMETER_MODIFIERS = 16;
    static final int ACCESS_MODIFIERS = 7;
    
    public Modifier() {
    }
    
    public static boolean isPublic(int n) {
        return (n & 0x1) != 0x0;
    }
    
    public static boolean isPrivate(int n) {
        return (n & 0x2) != 0x0;
    }
    
    public static boolean isProtected(int n) {
        return (n & 0x4) != 0x0;
    }
    
    public static boolean isStatic(int n) {
        return (n & 0x8) != 0x0;
    }
    
    public static boolean isFinal(int n) {
        return (n & 0x10) != 0x0;
    }
    
    public static boolean isSynchronized(int n) {
        return (n & 0x20) != 0x0;
    }
    
    public static boolean isVolatile(int n) {
        return (n & 0x40) != 0x0;
    }
    
    public static boolean isTransient(int n) {
        return (n & 0x80) != 0x0;
    }
    
    public static boolean isNative(int n) {
        return (n & 0x100) != 0x0;
    }
    
    public static boolean isInterface(int n) {
        return (n & 0x200) != 0x0;
    }
    
    public static boolean isAbstract(int n) {
        return (n & 0x400) != 0x0;
    }
    
    public static boolean isStrict(int n) {
        return (n & 0x800) != 0x0;
    }
    
    public static String toString(int n) {
        StringBuilder sb = new StringBuilder();
        if ((n & 0x1) != 0x0) {
            sb.append("public ");
        }
        if ((n & 0x4) != 0x0) {
            sb.append("protected ");
        }
        if ((n & 0x2) != 0x0) {
            sb.append("private ");
        }
        if ((n & 0x400) != 0x0) {
            sb.append("abstract ");
        }
        if ((n & 0x8) != 0x0) {
            sb.append("static ");
        }
        if ((n & 0x10) != 0x0) {
            sb.append("final ");
        }
        if ((n & 0x80) != 0x0) {
            sb.append("transient ");
        }
        if ((n & 0x40) != 0x0) {
            sb.append("volatile ");
        }
        if ((n & 0x20) != 0x0) {
            sb.append("synchronized ");
        }
        if ((n & 0x100) != 0x0) {
            sb.append("native ");
        }
        if ((n & 0x800) != 0x0) {
            sb.append("strictfp ");
        }
        if ((n & 0x200) != 0x0) {
            sb.append("interface ");
        }
        int length;
        if ((length = sb.length()) > 0) {
            return sb.toString().substring(0, length - 1);
        }
        return "";
    }
    
    static boolean isSynthetic(int n) {
        return (n & 0x1000) != 0x0;
    }
    
    static boolean isMandated(int n) {
        return (n & 0x8000) != 0x0;
    }
    
    public static int classModifiers() {
        return 3103;
    }
    
    public static int interfaceModifiers() {
        return 3087;
    }
    
    public static int constructorModifiers() {
        return 7;
    }
    
    public static int methodModifiers() {
        return 3391;
    }
    
    public static int fieldModifiers() {
        return 223;
    }
    
    public static int parameterModifiers() {
        return 16;
    }
    
    static {
        ((ReflectionFactory)AccessController.doPrivileged(new ReflectionFactory.GetReflectionFactoryAction())).setLangReflectAccess(new ReflectAccess());
    }
}
